# pik-django-utils #

This project aim is to provide common django project utils and tools 
for all PIK django projects.

It should provide guidance and tool recommendations for documentation, 
testing, etc.

This project is a part of `django-service-boilerplate`.

## Versioning ##

We use semantic versioning MAJOR.MINOR.MAINTENANCE scheme, where the project author increments:

 - MAJOR version when they make incompatible API changes,
 - MINOR version when they add functionality in a backwards-compatible manner, and
 - MAINTENANCE version when they make backwards-compatible bug fixes.

## Packages ##

 - `pik.core` - Django specific staff
 - `pik.libs` - Django specific modules and libraries
 - `pik.utils` - not Django specific small utils and goodness

----

 - [x] Follow https://packaging.python.org/
 - [x] Create `release.sh` file
 - [x] Create `utils.normalization`
 - [ ] Generate Django common settings
